@@ -1,4 +1,5 @@
-"""test_django_project URL Configuration
+"""
+test_django_project URL Configuration
 
 The `urlpatterns` list routes URLs to views. For more information please see:
     https://docs.djangoproject.com/en/3.1/topics/http/urls/
